@@ -1,5 +1,6 @@
 from ._auth_app import AuthApp
 from ._core_app import CoreApp
+from ._download_app import DownloadApp
 from ._dump_app import DumpApp
 from ._landing_app import LandingApp
 from ._migrate_app import MigrateApp
@@ -13,6 +14,7 @@ from ._run import RunApp
 __all__ = [
     "AuthApp",
     "CoreApp",
+    "DownloadApp",
     "DumpApp",
     "LandingApp",
     "MigrateApp",
