@@ -13,8 +13,10 @@ from cognite.client.testing import CogniteClientMock
 from cognite_toolkit._cdf_tk.client._toolkit_client import ToolkitClient
 
 from .api.canvas import CanvasAPI, IndustrialCanvasAPI
+from .api.charts import ChartsAPI
 from .api.dml import DMLAPI
 from .api.extended_data_modeling import ExtendedInstancesAPI
+from .api.extended_files import ExtendedFileMetadataAPI
 from .api.extended_functions import ExtendedFunctionsAPI
 from .api.extended_raw import ExtendedRawAPI
 from .api.extended_timeseries import ExtendedTimeSeriesAPI
@@ -60,6 +62,8 @@ class ToolkitClientMock(CogniteClientMock):
         #   - Use `spec_set=MyNestedAPI` for all nested APIs
         self.canvas = MagicMock(spec=CanvasAPI)
         self.canvas.industrial = MagicMock(spec_set=IndustrialCanvasAPI)
+        self.charts = MagicMock(spec_set=ChartsAPI)
+        self.files = MagicMock(spec_set=ExtendedFileMetadataAPI)
         self.functions = MagicMock(spec=ExtendedFunctionsAPI)
         self.functions.calls = MagicMock(spec_set=FunctionCallsAPI)
         self.functions.schedules = MagicMock(spec_set=FunctionSchedulesAPI)
